# -*- coding: utf-8 -*-



__name__ = "bayrell-file-system"
__version__ = "0.0.1"
__description__ = "Bayrell runtime library for python"
__license__ = "Apache License Version 2.0"
__author__ = "Ildar Bikmamatov"
__email__ = "ildar@bayrell.org"
__copyright__ = "Copyright 2016-2018"
__url__ = "https://github.com/bayrell/fs_py3"

